@@ -3,22 +3,21 @@ package MVC::Neaf::Request::Apache2;
 use strict;
 use warnings;
 
-our $VERSION = '0.2800_01';
+our $VERSION = 0.07;
 
 =head1 NAME
 
-MVC::Neaf::Request::Apache2 - Apache2 (mod_perl) driver for Not Even A Framework.
+MVC::Neaf::Request::Apache - Apache2 (mod_perl) driver for Not Even A Framework.
 
-=head1 WARNING
-
-B<This module is DEPRECATED and will be removed in Neaf 0.30.>
-
-Use L<Plack::Handler::Apache2> instead.
-
-=head1 SYNOPSIS
+=head1 DESCRIPTION
 
 Apache2 request that will invoke MVC::Neaf core functions from under mod_perl.
 
+Much to the author's disgrace, this module currently uses
+BOTH Apache2::RequestRec and Apache2::Request from libapreq.
+
+=head1 SYNOPSIS
+
 The following apache configuration should work with this module:
 
     LoadModule perl_module        modules/mod_perl.so
@@ -37,10 +36,9 @@ The following apache configuration should work with this module:
 
 =cut
 
-use Carp;
 use URI::Escape;
-use HTTP::Headers::Fast;
-use Module::Load;
+use HTTP::Headers;
+use Carp;
 
 my %fail_apache;
 BEGIN {
@@ -53,7 +51,7 @@ BEGIN {
         Apache2::Upload
         Apache2::Const
     )) {
-        eval { load $mod; 1 } and next;
+        eval "require $mod" and next; ## no critic
         # warn "Failed to load $mod: $@";
         $fail_apache{$mod} = $@;
     };
@@ -69,10 +67,6 @@ BEGIN {
     };
 };
 
-# TODO 0.30 remove the whole module
-carp __PACKAGE__." is DEPRECATED and will be REMOVED in 0.30. Use Plack::Handler::Apache2 instead."
-    if $ENV{MOD_PERL};
-
 use MVC::Neaf;
 use parent qw(MVC::Neaf::Request);
 
@@ -80,26 +74,11 @@ use parent qw(MVC::Neaf::Request);
 
 =cut
 
-my $client_ip_name;
 sub do_get_client_ip {
     my $self = shift;
 
     my $conn = $self->{driver_raw}->connection;
-    if (!$client_ip_name) {
-        # Apache 2.4 breaks API violently, so autodetect on first run,
-        # fall back to localhost
-        foreach (qw(remote_ip client_ip)) {
-            $conn->can($_) or next;
-            $client_ip_name = $_;
-            last;
-        };
-        if (!$client_ip_name) {
-            carp("WARNING: No client_ip found under Apache2, inform MVC::Neaf author");
-            return '127.0.0.1';
-        };
-    };
-
-    return $conn->$client_ip_name;
+    return $conn->remote_ip;
 };
 
 =head2 do_get_http_version
@@ -179,16 +158,6 @@ sub do_get_params {
     return \%hash;
 };
 
-=head2 do_get_param_as_array
-
-=cut
-
-sub do_get_param_as_array {
-    my ($self, $name) = @_;
-
-    return $self->{driver}->param( $name );
-};
-
 =head2 do_get_header_in()
 
 =cut
@@ -202,7 +171,7 @@ sub do_get_header_in {
         push @{ $head{$key} }, $val;
     });
 
-    return HTTP::Headers::Fast->new( %head );
+    return HTTP::Headers->new( %head );
 };
 
 =head2 do_get_upload( "name" )
@@ -224,25 +193,6 @@ sub do_get_upload {
     } : ();
 };
 
-=head2 do_get_body
-
-=cut
-
-sub do_get_body {
-    my $self = shift;
-
-    # use Apache2::RequestIO
-    # read until there's EOF, then concatenate & return
-    my $r = $self->{driver_raw};
-
-    my @buf = ('');
-    while ( $r->read( $buf[-1], 8192, 0 ) ) {
-        push @buf, '';
-    };
-
-    return join '', @buf;
-};
-
 =head2 do_reply( $status, $content )
 
 =cut
@@ -275,6 +225,8 @@ sub do_write {
     return $self->{driver_raw}->print( $data );
 };
 
+# TODO implement do_close, too!
+
 =head2 handler( $apache_request )
 
 A valid Apache2/mod_perl handler.
@@ -291,12 +243,8 @@ sub handler : method {
     my $self = $class->new(
         driver_raw => $r,
         driver => Apache2::Request->new($r),
-        query_string => $r->args,
     );
-    if (!$MVC::Neaf::Request::query_allowed{ $r->method }) {
-        $r->args('');
-    };
-    my $reply = MVC::Neaf::neaf()->handle_request( $self );
+    my $reply = MVC::Neaf->handle_request( $self );
 
     return Apache2::Const::OK();
 };
@@ -316,18 +264,4 @@ sub failed_startup {
        return %fail_apache ? \%fail_apache : ();
 };
 
-=head1 LICENSE AND COPYRIGHT
-
-This module is part of L<MVC::Neaf> suite.
-
-Copyright 2016-2023 Konstantin S. Uvarin C<khedin@cpan.org>.
-
-This program is free software; you can redistribute it and/or modify it
-under the terms of either: the GNU General Public License as published
-by the Free Software Foundation; or the Artistic License.
-
-See L<http://dev.perl.org/licenses/> for more information.
-
-=cut
-
 1;
