@@ -2,10 +2,7 @@ package MVC::Neaf::X;
 
 use strict;
 use warnings;
-our $VERSION = '0.2800_01';
-
-# This class is empty (yet).
-# See MVC::Neaf::Util::Base for implementation
+our $VERSION = 0.08;
 
 =head1 NAME
 
@@ -34,7 +31,7 @@ Some convenience methods here to help develop.
 
 =cut
 
-use parent qw(MVC::Neaf::Util::Base);
+use Carp;
 
 =head2 new( %options )
 
@@ -42,6 +39,12 @@ Will happily accept any args and pack them into self.
 
 =cut
 
+sub new {
+    my ($class, %opt) = @_;
+
+    return bless \%opt, $class;
+};
+
 =head2 my_croak( $message )
 
 Like croak() from Carp, but the message is prefixed
@@ -50,18 +53,13 @@ in which error occurred.
 
 =cut
 
-=head1 LICENSE AND COPYRIGHT
+sub my_croak {
+    my ($self, $msg) = @_;
 
-This module is part of L<MVC::Neaf> suite.
+    my $sub = [caller(1)]->[3];
+    $sub =~ s/.*:://;
 
-Copyright 2016-2023 Konstantin S. Uvarin C<khedin@cpan.org>.
-
-This program is free software; you can redistribute it and/or modify it
-under the terms of either: the GNU General Public License as published
-by the Free Software Foundation; or the Artistic License.
-
-See L<http://dev.perl.org/licenses/> for more information.
-
-=cut
+    croak join "", (ref $self || $self),"->",$sub,": ",$msg;
+};
 
 1;
